@@ -35,7 +35,8 @@ class ServerSettings:
                  reboot_on_crash: bool = None,
                  max_disk_usage_gb: int = None,
                  manual_sort_order: int = None,
-                 core_dump: bool = None) -> None:
+                 core_dump: bool = None,
+                 prefer_dedicated: bool = None) -> None:
         """Used to store settings on a server.
 
         Parameters
@@ -64,6 +65,8 @@ class ServerSettings:
             by default None
         core_dump : bool, optional
             by default None
+        prefer_dedicated : bool, optional
+            by default None
         """
 
         self.payload = {}
@@ -97,6 +100,8 @@ class ServerSettings:
                 raise InvalidStorageSize()
 
             self.payload["max_disk_usage_gb"] = max_disk_usage_gb
+        if prefer_dedicated is not None:
+            self.payload["prefer_dedicated"] = prefer_dedicated
 
     def csgo(self, slots: int = None, tickrate: int = None,
              game_token: str = None, rcon_password: str = None,
@@ -287,7 +292,6 @@ class ServerSettings:
         self.__game = True
 
         self.payload["game"] = "teamfortress2"
-
         if slots is not None:
             if slots < 5 or slots > 32:
                 raise InvalidSlotSize()
@@ -348,6 +352,8 @@ class ServerSettings:
         if self.__game:
             raise MultipleGames()
 
+        self.__game = True
+
         self.payload["game"] = "valheim"
         if password:
             self.payload["valheim_settings.password"] = password
